@@ -1,32 +1,22 @@
 # -*- coding: utf-8 -*-
-"""
-    celery.backends.amqp
-    ~~~~~~~~~~~~~~~~~~~~
-
-    The AMQP result backend.
-
-    This backend publishes results as messages.
-
-"""
-from __future__ import absolute_import
+"""The old AMQP result backend, deprecated and replaced by the RPC backend."""
+from __future__ import absolute_import, unicode_literals
 
 import socket
-
 from collections import deque
 from operator import itemgetter
 
-from kombu import Exchange, Queue, Producer, Consumer
+from kombu import Consumer, Exchange, Producer, Queue
 
 from celery import states
 from celery.exceptions import TimeoutError
-from celery.five import range, monotonic
-from celery.utils.functional import dictfilter
+from celery.five import monotonic, range
+from celery.utils import deprecated
 from celery.utils.log import get_logger
-from celery.utils.timeutils import maybe_s_to_ms
 
 from .base import BaseBackend
 
-__all__ = ['BacklogLimitExceeded', 'AMQPBackend']
+__all__ = ('BacklogLimitExceeded', 'AMQPBackend')
 
 logger = get_logger(__name__)
 
@@ -37,7 +27,7 @@ class BacklogLimitExceeded(Exception):
 
 def repair_uuid(s):
     # Historically the dashes in UUIDS are removed from AMQ entity names,
-    # but there is no known reason to.  Hopefully we'll be able to fix
+    # but there's no known reason to.  Hopefully we'll be able to fix
     # this in v4.0.
     return '%s-%s-%s-%s-%s' % (s[:8], s[8:12], s[12:16], s[16:20], s[20:])
 
@@ -47,7 +37,11 @@ class NoCacheQueue(Queue):
 
 
 class AMQPBackend(BaseBackend):
-    """Publishes results by sending messages."""
+    """The AMQP result backend.
+
+    Deprecated: Please use the RPC backend or a persistent backend.
+    """
+
     Exchange = Exchange
     Queue = NoCacheQueue
     Consumer = Consumer
@@ -68,26 +62,22 @@ class AMQPBackend(BaseBackend):
 
     def __init__(self, app, connection=None, exchange=None, exchange_type=None,
                  persistent=None, serializer=None, auto_delete=True, **kwargs):
+        deprecated.warn(
+            'The AMQP result backend', deprecation='4.0', removal='5.0',
+            alternative='Please use RPC backend or a persistent backend.')
         super(AMQPBackend, self).__init__(app, **kwargs)
         conf = self.app.conf
         self._connection = connection
         self.persistent = self.prepare_persistent(persistent)
         self.delivery_mode = 2 if self.persistent else 1
-        exchange = exchange or conf.CELERY_RESULT_EXCHANGE
-        exchange_type = exchange_type or conf.CELERY_RESULT_EXCHANGE_TYPE
+        exchange = exchange or conf.result_exchange
+        exchange_type = exchange_type or conf.result_exchange_type
         self.exchange = self._create_exchange(
             exchange, exchange_type, self.delivery_mode,
         )
-        self.serializer = serializer or conf.CELERY_RESULT_SERIALIZER
+        self.serializer = serializer or conf.result_serializer
         self.auto_delete = auto_delete
 
-        self.expires = None
-        if 'expires' not in kwargs or kwargs['expires'] is not None:
-            self.expires = self.prepare_expires(kwargs.get('expires'))
-        self.queue_arguments = dictfilter({
-            'x-expires': maybe_s_to_ms(self.expires),
-        })
-
     def _create_exchange(self, name, type='direct', delivery_mode=2):
         return self.Exchange(name=name,
                              type=type,
@@ -97,12 +87,14 @@ class AMQPBackend(BaseBackend):
 
     def _create_binding(self, task_id):
         name = self.rkey(task_id)
-        return self.Queue(name=name,
-                          exchange=self.exchange,
-                          routing_key=name,
-                          durable=self.persistent,
-                          auto_delete=self.auto_delete,
-                          queue_arguments=self.queue_arguments)
+        return self.Queue(
+            name=name,
+            exchange=self.exchange,
+            routing_key=name,
+            durable=self.persistent,
+            auto_delete=self.auto_delete,
+            expires=self.expires,
+        )
 
     def revive(self, channel):
         pass
@@ -115,18 +107,30 @@ class AMQPBackend(BaseBackend):
             return self.rkey(task_id), request.correlation_id or task_id
         return self.rkey(task_id), task_id
 
-    def store_result(self, task_id, result, status,
+    def store_result(self, task_id, result, state,
                      traceback=None, request=None, **kwargs):
-        """Send task return value and status."""
+        """Send task return value and state."""
         routing_key, correlation_id = self.destination_for(task_id, request)
         if not routing_key:
             return
+
+        payload = {'task_id': task_id, 'status': state,
+                   'result': self.encode_result(result, state),
+                   'traceback': traceback,
+                   'children': self.current_task_children(request)}
+        if self.app.conf.find_value_for_key('extended', 'result'):
+            payload['name'] = getattr(request, 'task_name', None)
+            payload['args'] = getattr(request, 'args', None)
+            payload['kwargs'] = getattr(request, 'kwargs', None)
+            payload['worker'] = getattr(request, 'hostname', None)
+            payload['retries'] = getattr(request, 'retries', None)
+            payload['queue'] = request.delivery_info.get('routing_key')\
+                if hasattr(request, 'delivery_info') \
+                and request.delivery_info else None
+
         with self.app.amqp.producer_pool.acquire(block=True) as producer:
             producer.publish(
-                {'task_id': task_id, 'status': status,
-                 'result': self.encode_result(result, status),
-                 'traceback': traceback,
-                 'children': self.current_task_children(request)},
+                payload,
                 exchange=self.exchange,
                 routing_key=routing_key,
                 correlation_id=correlation_id,
@@ -135,7 +139,6 @@ class AMQPBackend(BaseBackend):
                 declare=self.on_reply_declare(task_id),
                 delivery_mode=self.delivery_mode,
             )
-        return result
 
     def on_reply_declare(self, task_id):
         return [self._create_binding(task_id)]
@@ -149,12 +152,11 @@ class AMQPBackend(BaseBackend):
         if cache and cached_meta and \
                 cached_meta['status'] in READY_STATES:
             return cached_meta
-        else:
-            try:
-                return self.consume(task_id, timeout=timeout, no_ack=no_ack,
-                                    on_interval=on_interval)
-            except socket.timeout:
-                raise TimeoutError('The operation timed out.')
+        try:
+            return self.consume(task_id, timeout=timeout, no_ack=no_ack,
+                                on_interval=on_interval)
+        except socket.timeout:
+            raise TimeoutError('The operation timed out.')
 
     def get_task_meta(self, task_id, backlog_limit=1000):
         # Polling and using basic_get
@@ -180,8 +182,8 @@ class AMQPBackend(BaseBackend):
                 raise self.BacklogLimitExceeded(task_id)
 
             if latest:
-                payload = self._cache[task_id] = \
-                    self.meta_from_decoded(latest.payload)
+                payload = self._cache[task_id] = self.meta_from_decoded(
+                    latest.payload)
                 latest.requeue()
                 return payload
             else:
@@ -237,6 +239,7 @@ class AMQPBackend(BaseBackend):
         return [self._create_binding(task_id) for task_id in ids]
 
     def get_many(self, task_ids, timeout=None, no_ack=True,
+                 on_message=None, on_interval=None,
                  now=monotonic, getfields=itemgetter('status', 'task_id'),
                  READY_STATES=states.READY_STATES,
                  PROPAGATE_STATES=states.PROPAGATE_STATES, **kwargs):
@@ -259,15 +262,17 @@ class AMQPBackend(BaseBackend):
             push_cache = self._cache.__setitem__
             decode_result = self.meta_from_decoded
 
-            def on_message(message):
+            def _on_message(message):
                 body = decode_result(message.decode())
+                if on_message is not None:
+                    on_message(body)
                 state, uid = getfields(body)
                 if state in READY_STATES:
                     push_result(body) \
                         if uid in task_ids else push_cache(uid, body)
 
             bindings = self._many_bindings(task_ids)
-            with self.Consumer(channel, bindings, on_message=on_message,
+            with self.Consumer(channel, bindings, on_message=_on_message,
                                accept=self.accept, no_ack=no_ack):
                 wait = conn.drain_events
                 popleft = results.popleft
@@ -279,6 +284,8 @@ class AMQPBackend(BaseBackend):
                         ids.discard(task_id)
                         push_cache(task_id, state)
                         yield task_id, state
+                    if on_interval:
+                        on_interval()
 
     def reload_task_result(self, task_id):
         raise NotImplementedError(
@@ -301,10 +308,8 @@ class AMQPBackend(BaseBackend):
         raise NotImplementedError(
             'delete_group is not supported by this backend.')
 
-    def as_uri(self, include_password=True):
-        return 'amqp://'
-
-    def __reduce__(self, args=(), kwargs={}):
+    def __reduce__(self, args=(), kwargs=None):
+        kwargs = kwargs if kwargs else {}
         kwargs.update(
             connection=self._connection,
             exchange=self.exchange.name,
@@ -315,3 +320,6 @@ class AMQPBackend(BaseBackend):
             expires=self.expires,
         )
         return super(AMQPBackend, self).__reduce__(args, kwargs)
+
+    def as_uri(self, include_password=True):
+        return 'amqp://'
