@@ -7,7 +7,6 @@
     using K/V semantics like _get and _put.
 """
 from __future__ import absolute_import, unicode_literals
-from future.utils import raise_with_traceback
 
 from datetime import datetime, timedelta
 import sys
@@ -38,7 +37,8 @@ from celery.utils.log import get_logger
 from celery.utils.serialization import (create_exception_cls,
                                         ensure_serializable,
                                         get_pickleable_exception,
-                                        get_pickled_exception)
+                                        get_pickled_exception,
+                                        raise_with_context)
 from celery.utils.time import get_exponential_backoff_interval
 
 __all__ = ('BaseBackend', 'KeyValueStoreBackend', 'DisabledBackend')
@@ -454,7 +454,9 @@ class Backend(object):
                             self.max_sleep_between_retries_ms, True) / 1000
                         self._sleep(sleep_amount)
                     else:
-                        raise_with_traceback(BackendStoreError("failed to store result on the backend", task_id=task_id, state=state))
+                        raise_with_context(
+                            BackendStoreError("failed to store result on the backend", task_id=task_id, state=state),
+                        )
                 else:
                     raise
 
@@ -532,7 +534,9 @@ class Backend(object):
                             self.max_sleep_between_retries_ms, True) / 1000
                         self._sleep(sleep_amount)
                     else:
-                        raise_with_traceback(BackendGetMetaError("failed to get meta", task_id=task_id))
+                        raise_with_context(
+                            BackendGetMetaError("failed to get meta", task_id=task_id),
+                        )
                 else:
                     raise
 
@@ -735,7 +739,10 @@ class BaseKeyValueStoreBackend(Backend):
     def mget(self, keys):
         raise NotImplementedError('Does not support get_many')
 
-    def set(self, key, value, state):
+    def _set_with_state(self, key, value, state):
+        return self.set(key, value)
+
+    def set(self, key, value):
         raise NotImplementedError('Must implement the set method.')
 
     def delete(self, key):
@@ -855,12 +862,12 @@ class BaseKeyValueStoreBackend(Backend):
         if current_meta['status'] == states.SUCCESS:
             return result
 
-        self.set(self.get_key_for_task(task_id), self.encode(meta), state)
+        self._set_with_state(self.get_key_for_task(task_id), self.encode(meta), state)
         return result
 
     def _save_group(self, group_id, result):
-        self.set(self.get_key_for_group(group_id),
-                 self.encode({'result': result.as_tuple()}), states.SUCCESS)
+        self._set_with_state(self.get_key_for_group(group_id),
+                             self.encode({'result': result.as_tuple()}), states.SUCCESS)
         return result
 
     def _delete_group(self, group_id):
