@@ -31,7 +31,6 @@ except ImportError:
     from urlparse import unquote
 
 try:
-    import redis
     import redis.connection
     from kombu.transport.redis import get_redis_error_classes
 except ImportError:  # pragma: no cover
@@ -39,9 +38,9 @@ except ImportError:  # pragma: no cover
     get_redis_error_classes = None  # noqa
 
 try:
-    from redis import sentinel
+    import redis.sentinel
 except ImportError:
-    sentinel = None
+    pass
 
 __all__ = ('RedisBackend', 'SentinelBackend')
 
@@ -410,22 +409,40 @@ class RedisBackend(BaseKeyValueStoreBackend, AsyncBackendMixin):
         # this flag.
         pass
 
+    @cached_property
+    def _chord_zset(self):
+        transport_options = self.app.conf.get(
+            'result_backend_transport_options', {}
+        )
+        return transport_options.get('result_chord_ordered', False)
+
     def on_chord_part_return(self, request, state, result,
                              propagate=None, **kwargs):
         app = self.app
-        tid, gid = request.id, request.group
+        tid, gid, group_index = request.id, request.group, request.group_index
         if not gid or not tid:
             return
+        if group_index is None:
+            group_index = '+inf'
 
         client = self.client
         jkey = self.get_key_for_group(gid, '.j')
         tkey = self.get_key_for_group(gid, '.t')
         result = self.encode_result(result, state)
         with client.pipeline() as pipe:
-            pipeline = pipe \
-                .rpush(jkey, self.encode([1, tid, state, result])) \
-                .llen(jkey) \
-                .get(tkey)
+            if self._chord_zset:
+                pipeline = (pipe
+                    .zadd(jkey, {
+                        self.encode([1, tid, state, result]): group_index
+                    })
+                    .zcount(jkey, '-inf', '+inf')
+                )
+            else:
+                pipeline = (pipe
+                    .rpush(jkey, self.encode([1, tid, state, result]))
+                    .llen(jkey)
+                )
+            pipeline = pipeline.get(tkey)
 
             if self.expires is not None:
                 pipeline = pipeline \
@@ -442,9 +459,11 @@ class RedisBackend(BaseKeyValueStoreBackend, AsyncBackendMixin):
             if readycount == total:
                 decode, unpack = self.decode, self._unpack_chord_result
                 with client.pipeline() as pipe:
-                    resl, = pipe \
-                        .lrange(jkey, 0, total) \
-                        .execute()
+                    if self._chord_zset:
+                        pipeline = pipe.zrange(jkey, 0, -1)
+                    else:
+                        pipeline = pipe.lrange(jkey, 0, total)
+                    resl, = pipeline.execute()
                 try:
                     callback.delay([unpack(tup, decode) for tup in resl])
                     with client.pipeline() as pipe:
@@ -516,7 +535,7 @@ class RedisBackend(BaseKeyValueStoreBackend, AsyncBackendMixin):
 class SentinelBackend(RedisBackend):
     """Redis sentinel task result store."""
 
-    sentinel = sentinel
+    sentinel = getattr(redis, "sentinel", None)
 
     def __init__(self, *args, **kwargs):
         if self.sentinel is None:
