@@ -20,7 +20,7 @@
 .. cmdoption:: -S, --scheduler
 
     Scheduler class to use.
-    Default is :class:`celery.beat.PersistentScheduler`.
+    Default is :class:`{default}`.
 
 .. cmdoption:: --max-interval
 
@@ -71,7 +71,7 @@ from functools import partial
 from celery.bin.base import Command, daemon_options
 from celery.platforms import detached, maybe_drop_privileges
 
-__all__ = ['beat']
+__all__ = ('beat',)
 
 HELP = __doc__
 
@@ -115,7 +115,7 @@ class beat(Command):
         bopts.add_argument(
             '-s', '--schedule', default=c.beat_schedule_filename)
         bopts.add_argument('--max-interval', type=float)
-        bopts.add_argument('-S', '--scheduler')
+        bopts.add_argument('-S', '--scheduler', default=c.beat_scheduler)
         bopts.add_argument('-l', '--loglevel', default='WARN')
 
         daemon_options(parser, default_pidfile='celerybeat.pid')
