@@ -84,10 +84,11 @@ have it block until the task is finished.
    database backends.
 """
 from __future__ import absolute_import, unicode_literals
+
 from celery import Task
 from celery.result import AsyncResult
 
-__all__ = ['AbortableAsyncResult', 'AbortableTask']
+__all__ = ('AbortableAsyncResult', 'AbortableTask')
 
 
 """
@@ -107,7 +108,7 @@ ABORTED = 'ABORTED'
 
 
 class AbortableAsyncResult(AsyncResult):
-    """Represents a abortable result.
+    """Represents an abortable result.
 
     Specifically, this gives the `AsyncResult` a :meth:`abort()` method,
     that sets the state of the underlying Task to `'ABORTED'`.
