@@ -46,12 +46,22 @@ class ManagerMixin(object):
         # type: (Sequence[AsyncResult]) -> Sequence[str]
         return [res.id for res in r if res.id not in res.backend._cache]
 
-    def wait_for(self, fun, catch,
-                 desc='thing', args=(), kwargs=None, errback=None,
-                 max_retries=10, interval_start=0.1, interval_step=0.5,
-                 interval_max=5.0, emit_warning=False, **options):
-        # type: (Callable, Sequence[Any], str, Tuple, Dict, Callable,
-        #        int, float, float, float, bool, **Any) -> Any
+    def wait_for(
+        self,
+        fun,  # type: Callable
+        catch,  # type: Sequence[Any]
+        desc="thing",  # type: str
+        args=(),  # type: Tuple
+        kwargs=None,  # type: Dict
+        errback=None,  # type: Callable
+        max_retries=10,  # type: int
+        interval_start=0.1,  # type: float
+        interval_step=0.5,  # type: float
+        interval_max=5.0,  # type: float
+        emit_warning=False,  # type: bool
+        **options  # type: Any
+    ):
+        # type: (...) -> Any
         """Wait for event to happen.
 
         The `catch` argument specifies the exception that means the event
