@@ -7,19 +7,19 @@ soon as possible, and that shall not load any third party modules.
 Parts of this module is Copyright by Werkzeug Team.
 """
 from __future__ import absolute_import, unicode_literals
+
 import operator
 import sys
 from functools import reduce
 from importlib import import_module
 from types import ModuleType
-from .five import bytes_if_py2, items, string, string_t
 
-__all__ = ['Proxy', 'PromiseProxy', 'try_import', 'maybe_evaluate']
+from .five import PY3, bytes_if_py2, items, string, string_t
+
+__all__ = ('Proxy', 'PromiseProxy', 'try_import', 'maybe_evaluate')
 
 __module__ = __name__  # used by Proxy class body
 
-PY3 = sys.version_info[0] == 3
-
 
 def _default_cls_attr(name, type_, cls_value):
     # Proxy uses properties to forward the standard
@@ -310,7 +310,7 @@ class PromiseProxy(Proxy):
     promise will only evaluate it once.
     """
 
-    __slots__ = ('__pending__',)
+    __slots__ = ('__pending__', '__weakref__')
 
     def _get_current_object(self):
         try:
@@ -390,6 +390,7 @@ def maybe_evaluate(obj):
 
 # import fails in python 2.5. fallback to reduce in stdlib
 
+
 MODULE_DEPRECATED = """
 The module %s is deprecated and will be removed in a future version.
 """
@@ -420,6 +421,7 @@ def _compat_periodic_task_decorator(*args, **kwargs):
     from celery.task import periodic_task
     return periodic_task(*args, **kwargs)
 
+
 COMPAT_MODULES = {
     'celery': {
         'execute': {
@@ -541,8 +543,11 @@ def create_module(name, attrs, cls_attrs=None, pkg=None,
     return module
 
 
-def recreate_module(name, compat_modules=(), by_module={}, direct={},
+def recreate_module(name, compat_modules=None, by_module=None, direct=None,
                     base=LazyModule, **attrs):
+    compat_modules = compat_modules or ()
+    by_module = by_module or {}
+    direct = direct or {}
     old_module = sys.modules[name]
     origins = get_origins(by_module)
     compat_modules = COMPAT_MODULES.get(name, ())
@@ -553,12 +558,12 @@ def recreate_module(name, compat_modules=(), by_module={}, direct={},
     )))
     if sys.version_info[0] < 3:
         _all = [s.encode() for s in _all]
-    cattrs = dict(
-        _compat_modules=compat_modules,
-        _all_by_module=by_module, _direct=direct,
-        _object_origins=origins,
-        __all__=_all,
-    )
+    cattrs = {
+        '_compat_modules': compat_modules,
+        '_all_by_module': by_module, '_direct': direct,
+        '_object_origins': origins,
+        '__all__': _all,
+    }
     new_module = create_module(name, attrs, cls_attrs=cattrs, base=base)
     new_module.__dict__.update({
         mod: get_compat_module(new_module, mod) for mod in compat_modules
