@@ -367,10 +367,15 @@ class Request(object):
             'logfile': logfile,
             'is_eager': False,
         }, **embed or {})
-        retval = trace_task(self.task, self.id, self._args, self._kwargs, request,
-                            hostname=self._hostname, loader=self._app.loader,
-                            app=self._app)[0]
-        self.acknowledge()
+
+        retval, I, _, _ = trace_task(self.task, self.id, self._args, self._kwargs, request,
+                                     hostname=self._hostname, loader=self._app.loader,
+                                     app=self._app)
+
+        if I:
+            self.reject(requeue=False)
+        else:
+            self.acknowledge()
         return retval
 
     def maybe_expire(self):
@@ -505,7 +510,7 @@ class Request(object):
             )
             ack = self.task.acks_on_failure_or_timeout
             if reject:
-                requeue = not self.delivery_info.get('redelivered')
+                requeue = True
                 self.reject(requeue=requeue)
                 send_failed_event = False
             elif ack:
@@ -621,6 +626,11 @@ class Request(object):
         request.update(**embed or {})
         return Context(request)
 
+    @cached_property
+    def group_index(self):
+        # used by backend.on_chord_part_return to order return values in group
+        return self._request_dict.get('group_index')
+
 
 def create_request_cls(base, task, pool, hostname, eventer,
                        ref=ref, revoked_tasks=revoked_tasks,
